compose

package
v0.0.0-...-4519c83 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2018 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package compose is the internal version of the API.

Index

Constants

const GroupName = "compose.docker.com"

GroupName is the group name used to register these objects

Variables

var (
	// SchemeBuilder collects functions that add things to a scheme. It's to allow
	// code to compile without explicitly referencing generated types. You should
	// declare one in each package that will have generated deep copy or conversion
	// functions.
	SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes)

	// AddToScheme applies all the stored functions to the scheme. A non-nil error
	// indicates that one function failed and the attempt was abandoned.
	AddToScheme = SchemeBuilder.AddToScheme
)
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}

SchemeGroupVersion is group version used to register these objects

Functions

func Kind

func Kind(kind string) schema.GroupKind

Kind takes an unqualified kind and returns back a Group qualified GroupKind

func RegisterDeepCopies deprecated

func RegisterDeepCopies(scheme *runtime.Scheme) error

Deprecated: RegisterDeepCopies adds deep-copy functions to the given scheme. Public to allow building arbitrary schemes.

func Resource

func Resource(resource string) schema.GroupResource

Resource takes an unqualified resource and returns back a Group qualified GroupResource

Types

type ImpersonationConfig

type ImpersonationConfig struct {
	// UserName is the username to impersonate on each request.
	UserName string
	// Groups are the groups to impersonate on each request.
	Groups []string
	// Extra is a free-form field which can be used to link some authentication information
	// to authorization information.  This field allows you to impersonate it.
	Extra map[string][]string
}

ImpersonationConfig holds information use to impersonate calls from the compose controller

func (*ImpersonationConfig) DeepCopy

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new ImpersonationConfig.

func (*ImpersonationConfig) DeepCopyInto

func (in *ImpersonationConfig) DeepCopyInto(out *ImpersonationConfig)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type Owner

type Owner struct {
	metav1.TypeMeta
	metav1.ObjectMeta
	Owner ImpersonationConfig
}

Owner defines the owner of a stack. It is used to impersonate the controller calls to kubernetes api.

func (*Owner) DeepCopy

func (x *Owner) DeepCopy() *Owner

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new Owner.

func (*Owner) DeepCopyInto

func (in *Owner) DeepCopyInto(out *Owner)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*Owner) DeepCopyObject

func (x *Owner) DeepCopyObject() runtime.Object

type OwnerList

type OwnerList struct {
	metav1.TypeMeta
	metav1.ListMeta
	Items []Owner
}

OwnerList defines a list of owner.

func (*OwnerList) DeepCopy

func (x *OwnerList) DeepCopy() *OwnerList

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new OwnerList.

func (*OwnerList) DeepCopyInto

func (in *OwnerList) DeepCopyInto(out *OwnerList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type Stack

type Stack struct {
	metav1.TypeMeta
	metav1.ObjectMeta
	Spec   StackSpec
	Status StackStatus
}

Stack defines a stack object to be register in the kubernetes API +genclient=true +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

func (*Stack) DeepCopy

func (x *Stack) DeepCopy() *Stack

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new Stack.

func (*Stack) DeepCopyInto

func (in *Stack) DeepCopyInto(out *Stack)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*Stack) DeepCopyObject

func (x *Stack) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (Stack) GetGeneration

func (pc Stack) GetGeneration() int64

GetGeneration returns the Generation

func (*Stack) GetObjectMeta

func (pc *Stack) GetObjectMeta() *metav1.ObjectMeta

GetObjectMeta returns the ObjectMeta

func (*Stack) GetSpec

func (pc *Stack) GetSpec() interface{}

GetSpec returns the spec

func (*Stack) GetStatus

func (pc *Stack) GetStatus() interface{}

GetStatus returns the status

func (Stack) NewStatus

func (Stack) NewStatus() interface{}

NewStatus is newStatus

func (*Stack) SetGeneration

func (pc *Stack) SetGeneration(generation int64)

SetGeneration sets the Generation

func (*Stack) SetSpec

func (pc *Stack) SetSpec(s interface{})

SetSpec sets the spec

func (*Stack) SetStatus

func (pc *Stack) SetStatus(s interface{})

SetStatus sets the status

type StackList

type StackList struct {
	metav1.TypeMeta
	metav1.ListMeta
	Items []Stack
}

StackList defines a list of stacks +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object

func (*StackList) DeepCopy

func (x *StackList) DeepCopy() *StackList

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new StackList.

func (*StackList) DeepCopyInto

func (in *StackList) DeepCopyInto(out *StackList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*StackList) DeepCopyObject

func (x *StackList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type StackPhase

type StackPhase string

StackPhase defines the status phase in which the stack is.

const (
	// Available means the stack is available.
	StackAvailable StackPhase = "Available"
	// Progressing means the deployment is progressing.
	StackProgressing StackPhase = "Progressing"
	// StackFailure is added in a stack when one of its members fails to be created
	// or deleted.
	StackFailure StackPhase = "Failure"
)

These are valid conditions of a stack.

type StackSpec

type StackSpec struct {
	ComposeFile string
	Owner       ImpersonationConfig
}

StackSpec defines the desired state of Stack

func (*StackSpec) DeepCopy

func (x *StackSpec) DeepCopy() *StackSpec

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new StackSpec.

func (*StackSpec) DeepCopyInto

func (in *StackSpec) DeepCopyInto(out *StackSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type StackStatus

type StackStatus struct {
	Phase   StackPhase
	Message string
}

StackStatus defines the observed state of Stack

func (*StackStatus) DeepCopy

func (x *StackStatus) DeepCopy() *StackStatus

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new StackStatus.

func (*StackStatus) DeepCopyInto

func (in *StackStatus) DeepCopyInto(out *StackStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Directories

Path Synopsis
Package v1beta1 holds the v1beta1 versions of our stack structures.
Package v1beta1 holds the v1beta1 versions of our stack structures.

Jump to