Documentation
¶
Overview ¶
Package compose is the internal version of the API.
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func RegisterDeepCopies(scheme *runtime.Scheme) errordeprecated
- func Resource(resource string) schema.GroupResource
- type ImpersonationConfig
- type Owner
- type OwnerList
- type Stack
- func (x *Stack) DeepCopy() *Stack
- func (in *Stack) DeepCopyInto(out *Stack)
- func (x *Stack) DeepCopyObject() runtime.Object
- func (pc Stack) GetGeneration() int64
- func (pc *Stack) GetObjectMeta() *metav1.ObjectMeta
- func (pc *Stack) GetSpec() interface{}
- func (pc *Stack) GetStatus() interface{}
- func (Stack) NewStatus() interface{}
- func (pc *Stack) SetGeneration(generation int64)
- func (pc *Stack) SetSpec(s interface{})
- func (pc *Stack) SetStatus(s interface{})
- type StackList
- type StackPhase
- type StackSpec
- type StackStatus
Constants ¶
const GroupName = "compose.docker.com"
GroupName is the group name used to register these objects
Variables ¶
var ( // SchemeBuilder collects functions that add things to a scheme. It's to allow // code to compile without explicitly referencing generated types. You should // declare one in each package that will have generated deep copy or conversion // functions. SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme applies all the stored functions to the scheme. A non-nil error // indicates that one function failed and the attempt was abandoned. AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func RegisterDeepCopies
deprecated
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns back a Group qualified GroupResource
Types ¶
type ImpersonationConfig ¶
type ImpersonationConfig struct {
// UserName is the username to impersonate on each request.
UserName string
// Groups are the groups to impersonate on each request.
Groups []string
// Extra is a free-form field which can be used to link some authentication information
// to authorization information. This field allows you to impersonate it.
Extra map[string][]string
}
ImpersonationConfig holds information use to impersonate calls from the compose controller
func (*ImpersonationConfig) DeepCopy ¶
func (x *ImpersonationConfig) DeepCopy() *ImpersonationConfig
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new ImpersonationConfig.
func (*ImpersonationConfig) DeepCopyInto ¶
func (in *ImpersonationConfig) DeepCopyInto(out *ImpersonationConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Owner ¶
type Owner struct {
metav1.TypeMeta
metav1.ObjectMeta
Owner ImpersonationConfig
}
Owner defines the owner of a stack. It is used to impersonate the controller calls to kubernetes api.
func (*Owner) DeepCopy ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new Owner.
func (*Owner) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Owner) DeepCopyObject ¶
type OwnerList ¶
OwnerList defines a list of owner.
func (*OwnerList) DeepCopy ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new OwnerList.
func (*OwnerList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Stack ¶
type Stack struct {
metav1.TypeMeta
metav1.ObjectMeta
Spec StackSpec
Status StackStatus
}
Stack defines a stack object to be register in the kubernetes API +genclient=true +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*Stack) DeepCopy ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new Stack.
func (*Stack) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Stack) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (Stack) GetGeneration ¶
GetGeneration returns the Generation
func (*Stack) GetObjectMeta ¶
func (pc *Stack) GetObjectMeta() *metav1.ObjectMeta
GetObjectMeta returns the ObjectMeta
func (*Stack) SetGeneration ¶
SetGeneration sets the Generation
type StackList ¶
StackList defines a list of stacks +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
func (*StackList) DeepCopy ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new StackList.
func (*StackList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*StackList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type StackPhase ¶
type StackPhase string
StackPhase defines the status phase in which the stack is.
const ( // Available means the stack is available. StackAvailable StackPhase = "Available" // Progressing means the deployment is progressing. StackProgressing StackPhase = "Progressing" // StackFailure is added in a stack when one of its members fails to be created // or deleted. StackFailure StackPhase = "Failure" )
These are valid conditions of a stack.
type StackSpec ¶
type StackSpec struct {
ComposeFile string
Owner ImpersonationConfig
}
StackSpec defines the desired state of Stack
func (*StackSpec) DeepCopy ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new StackSpec.
func (*StackSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type StackStatus ¶
type StackStatus struct {
Phase StackPhase
Message string
}
StackStatus defines the observed state of Stack
func (*StackStatus) DeepCopy ¶
func (x *StackStatus) DeepCopy() *StackStatus
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, creating a new StackStatus.
func (*StackStatus) DeepCopyInto ¶
func (in *StackStatus) DeepCopyInto(out *StackStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.